//
// EIOReadTest.cpp
//
//
// This simple application configures the EIO driver as inputs
// and displays the readings on the debug port.
//
// Applied Data Systems
//
// 28Aug2003 720020-11551 ak
// - initial release
//

#include "stdafx.h"
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include "eio_ctrl.h"


//-------------------------------------------------------------------
//-------------------------------------------------------------------
int WINAPI WinMain(	HINSTANCE hInstance,
					HINSTANCE hPrevInstance,
					LPTSTR    lpCmdLine,
					int       nCmdShow)
{
	DWORD dwReading, dwNumBytes, dwBytesRead;
	DWORD mask = 0x0000;   // EIO1: all inputs
	HANDLE hEIO;
	int i, j=0;

    RETAILMSG(TRUE,(L"\r\nEIOReadTest 720020-11551: Configures EIO as inputs. Displays readings on debug port.\r\n"));

	// Open and initialize port
	hEIO = CreateFile(TEXT("EIO1:"), GENERIC_READ, FILE_SHARE_READ,NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
	if(hEIO==INVALID_HANDLE_VALUE)
	{
		RETAILMSG(TRUE,(_T("Error: Unable to open EIO1: (error # %d)\r\n"),GetLastError()));
		RETAILMSG(TRUE,(_T("Program aborted.\r\n")));
		return 1;
	}
	
	if(!DeviceIoControl(hEIO,IOCTL_EIO_CONFIG_PORTS,&mask,sizeof(DWORD),NULL,0,&dwNumBytes,NULL ))
	{
		RETAILMSG(TRUE,(_T("Error: Unable to set direction of EIO1: (error # %d)\r\n"),GetLastError()));
		RETAILMSG(TRUE,(_T("Program aborted.\r\n")));
		return 2;
	}
    
	// Prepare to display data
	RETAILMSG(TRUE,(L"Bit #:  9 8 7 6 5 4 3 2 1 0\r\n"));

	// Display data indefinitely
	while(TRUE)
	{		
		// return cursor to start of line
		// display spinning character to indicate activity
		j++;
		switch (j%4)  // returns 0-3
		{
			case 0 : RETAILMSG(TRUE, (_T("\r    -  "))); break;
			case 1 : RETAILMSG(TRUE, (_T("\r    \\  "))); break;
			case 2 : RETAILMSG(TRUE, (_T("\r    |  "))); break;
			case 3 : RETAILMSG(TRUE, (_T("\r    /  "))); break;
		}

		// read the data
		ReadFile(hEIO, &dwReading, sizeof(dwReading), &dwBytesRead,NULL);

		// display the data in binary format
		for(i=9 ; i>=0; i--)
			RETAILMSG(TRUE, (_T("%2d"), (dwReading>>i)&0x01 ));

		// display in hex, too
		RETAILMSG(TRUE, (_T("  (0x%03X)  "), dwReading ));

		Sleep(100);
	}

	RETAILMSG(TRUE,(L"\r\nEIOReadTest: Complete (should never get here).\r\n"));

	return 0;

}

